@@ -1,6 +1,6 @@
 package Bundle::Everything;
 
-$VERSION = '0.03'
+$VERSION = '0.04'
 
 1;
 
@@ -123,6 +123,18 @@ AnyData
 
 Apache
 
+Apache2::AuthCookieDBI
+
+Apache2::AuthNetLDAP
+
+Apache2::AuthenNTLM
+
+Apache2::AuthenSmb
+
+Apache2::DBI
+
+Apache2::PageKit
+
 Apache::ACEProxy
 
 Apache::ASP
@@ -149,6 +161,8 @@ Apache::AuthChecker
 
 Apache::AuthCookie
 
+Apache::AuthCookieDBI
+
 Apache::AuthCookieLDAP
 
 Apache::AuthExpire
@@ -249,8 +263,6 @@ Apache::Dynagzip
 
 Apache::Embperl
 
-Apache::EmbperlChain
-
 Apache::FakeCookie
 
 Apache::FakeRequest
@@ -385,6 +397,8 @@ Apache::ShowRequest
 
 Apache::SimpleReplace
 
+Apache::SiteControl
+
 Apache::SmallProf
 
 Apache::SpeedLimit
@@ -447,6 +461,8 @@ App::Config
 
 App::Info
 
+App::Modular
+
 App::Options
 
 AppConfig
@@ -461,6 +477,8 @@ Archie
 
 Archive::Ar
 
+Archive::Cabinet
+
 Archive::Parity
 
 Archive::Tar
@@ -499,6 +517,8 @@ Astro::SLA
 
 Astro::SkyCoords
 
+Astro::SpaceTrack
+
 Astro::Sunrise
 
 Astro::Time
@@ -547,6 +567,8 @@ Audio::Moosic
 
 Audio::OSS
 
+Audio::Play::MPG321
+
 Audio::SoundFile
 
 AudioCD
@@ -633,6 +655,8 @@ Biblio::Document::Parser
 
 Biblio::Thesaurus
 
+Bio::ASN1::EntrezGene
+
 Bio::Affymetrix
 
 Bio::GMOD
@@ -711,6 +735,8 @@ Business::NoChex
 
 Business::OnlinePayment
 
+Business::OnlinePayment::Cybersource
+
 Business::OnlinePayment::E2Payments
 
 Business::OnlinePayment::Moneris
@@ -751,6 +777,10 @@ CGI::Application::GDGraph::lines_ap
 
 CGI::Application::PhotoGallery
 
+CGI::Application::Plugin::CompressGzip
+
+CGI::Application::Plugin::HtmlTidy
+
 CGI::Application::Plugin::Stream
 
 CGI::ArgChecker
@@ -785,6 +815,8 @@ CGI::FormMagick
 
 CGI::Formalware
 
+CGI::Getopt
+
 CGI::Imagemap
 
 CGI::Lite
@@ -843,6 +875,8 @@ CGI::URI2param
 
 CGI::Untaint::Filenames
 
+CGI::UploadEasy
+
 CGI::Validate
 
 CGI::WML
@@ -855,6 +889,8 @@ CGI_Lite
 
 CIPP
 
+CLucene
+
 CORBA::IDLtree
 
 CORBA::IOP::IOR
@@ -877,6 +913,8 @@ Cache::FastMemoryCache
 
 Cache::Mmap
 
+Cache::Repository
+
 Calendar::CSA
 
 Callback
@@ -939,6 +977,8 @@ Class::Accessor
 
 Class::ArrayObjects
 
+Class::AutoloadCAN
+
 Class::BlackHole
 
 Class::Classless
@@ -957,6 +997,10 @@ Class::DBI::Oracle
 
 Class::DBI::Plugin::CountSearch
 
+Class::DBI::Plugin::DeepAbstractSearch
+
+Class::DBI::Plugin::DeepAbstractSearchPager
+
 Class::DBI::Plugin::Pager
 
 Class::DBI::Template
@@ -967,6 +1011,8 @@ Class::DBI::mysql
 
 Class::Data::Reloadable
 
+Class::DataStore
+
 Class::Date
 
 Class::Decorator
@@ -1067,8 +1113,12 @@ Concurrent
 
 Config::Abstract
 
+Config::Find
+
 Config::FreeForm
 
+Config::General
+
 Config::Ini
 
 Config::IniFiles
@@ -1079,6 +1129,8 @@ Config::Properties
 
 Config::Scoped
 
+Config::YUM
+
 ConfigReader::Simple
 
 Conjury::C
@@ -1201,8 +1253,6 @@ Crypt::OpenSSL::X509
 
 Crypt::PGP5
 
-Crypt::PRSG
-
 Crypt::PassGen
 
 Crypt::Passwd
@@ -1251,6 +1301,8 @@ Crypt::UnixCrypt
 
 Crypt::UnixCrypt_XS
 
+Crypt::X509
+
 Curses
 
 Curses::Application
@@ -1313,6 +1365,8 @@ DBD::ODBC
 
 DBD::Oracle
 
+DBD::Pg
+
 DBD::PgPP
 
 DBD::PrimeBase
@@ -1369,6 +1423,8 @@ DBIx::CodeKit
 
 DBIx::Copy
 
+DBIx::Counter
+
 DBIx::DBSchema
 
 DBIx::FetchLoop
@@ -1493,6 +1549,8 @@ Data::DRef
 
 Data::Denter
 
+Data::Describe
+
 Data::Diff
 
 Data::Favorites
@@ -1523,8 +1581,12 @@ Data::MultiValuedHash
 
 Data::Paginate
 
+Data::Postponed
+
 Data::Random
 
+Data::RandomPerson
+
 Data::Reporter
 
 Data::Search
@@ -1533,12 +1595,18 @@ Data::SecsPack
 
 Data::Serializer
 
+Data::Sofu
+
 Data::Stash
 
+Data::Tabular
+
 Data::Tabular::Dumper
 
 Data::TimeSeries
 
+Data::Traverse
+
 Data::Validate
 
 Data::Validate::Domain
@@ -1663,6 +1731,8 @@ Devel::DumpStack
 
 Devel::Fail::Make
 
+Devel::Fail::MakeTest
+
 Devel::FindGlobals
 
 Devel::Hints
@@ -1725,6 +1795,8 @@ Digest::MD4
 
 Digest::MD5
 
+Digest::MD5::File
+
 Digest::Perl::MD5
 
 Digest::SHA
@@ -1739,6 +1811,8 @@ Dir::Purge
 
 ERG
 
+Ekahau
+
 ElectricArc
 
 Emacs
@@ -1757,6 +1831,8 @@ Embedix::ECD
 
 Encode::Arabic
 
+Encode::HEBCI
+
 Encode::HanConvert
 
 Encode::HanDetect
@@ -1785,6 +1861,8 @@ Error::TryCatch
 
 Event
 
+Event::RPC
+
 Event::Stats
 
 Event::tcp
@@ -1871,6 +1949,8 @@ File::Find::Rule::XPath
 
 File::Flock
 
+File::Format::RIFF
+
 File::Glob
 
 File::LckPwdF
@@ -1893,6 +1973,8 @@ File::Remote
 
 File::Remove
 
+File::Rename
+
 File::Repl
 
 File::Rsync
@@ -1919,6 +2001,8 @@ File::Stream
 
 File::Sync
 
+File::Tabular
+
 File::Tail
 
 File::Temp
@@ -1935,6 +2019,8 @@ File::chmod
 
 File::lockf
 
+File::sudoers
+
 Filesys::Df
 
 Filesys::DiskFree
@@ -2013,6 +2099,8 @@ Finance::Shares::MySQL
 
 Finance::Streamer
 
+Find::File::Object
+
 FindBin
 
 FindBin::libs
@@ -2055,6 +2143,8 @@ GD::Graph3d
 
 GD::Image::AnimatedGif
 
+GD::Image::CopyIFS
+
 GD::Image::Orientation
 
 GD::Image::Thumbnail
@@ -2091,6 +2181,8 @@ Games::Bingo
 
 Games::Cards
 
+Games::Cards::Poker
+
 Games::Crosswords
 
 Games::Dice
@@ -2103,12 +2195,16 @@ Games::Go::GoPair
 
 Games::Maze
 
+Games::Multiplayer::Manager
+
 Games::Object
 
 Games::Score
 
 Games::Sequential
 
+Games::Tournament::BlackJack
+
 Games::Traveller::UWP
 
 Games::WordFind
@@ -2123,18 +2219,22 @@ Genezzo
 
 Geo::Coordinates::Convert
 
+Geo::Coordinates::OSGB
+
 Geo::Coordinates::UTM
 
 Geo::CountryFlags
 
 Geo::Distance
 
-Geo::GPS::Data
-
 Geo::IP
 
+Geo::IP2Location
+
 Geo::METAR
 
+Geo::PostalAddress
+
 Geo::Projection
 
 Geo::ShapeFile
@@ -2157,6 +2257,8 @@ Getopt::Declare
 
 Getopt::EvaP
 
+Getopt::GUI::Long
+
 Getopt::GetArgs
 
 Getopt::Gnu
@@ -2183,6 +2285,8 @@ Gnome
 
 Gnome2
 
+Gnome2::VFS
+
 GnuPG
 
 GnuPG::Interface
@@ -2223,8 +2327,12 @@ Gtk2
 
 Gtk2::Ex::DBI
 
+Gtk2::Ex::Datasheet::DBI
+
 Gtk2::Ex::FormFactory
 
+Gtk2::Ex::PopupWindow
+
 Gtk2::MozEmbed
 
 Gtk2::TrayManager
@@ -2237,6 +2345,8 @@ HPUX::Ioscan
 
 HPUX::LVM
 
+HPUX::Pstat
+
 HPUX::SDUX
 
 HTML::ActiveLink
@@ -2257,6 +2367,8 @@ HTML::CalendarMonthDB
 
 HTML::Chunks
 
+HTML::Debug
+
 HTML::Demoroniser
 
 HTML::Diff
@@ -2531,6 +2643,8 @@ IPC::ChildSafe
 
 IPC::DirQueue
 
+IPC::Door
+
 IPC::Filter
 
 IPC::LDT
@@ -2559,12 +2673,16 @@ IPChains::PortFW
 
 IPTables::IPv4::IPQueue
 
+Image::ASCII
+
 Image::DS9
 
 Image::DeAnim
 
 Image::Dot
 
+Image::Epeg
+
 Image::ExifTool
 
 Image::GD::Thumbnail
@@ -2671,6 +2789,8 @@ LWP::UA
 
 LWP::UserAgent
 
+LWPx::ParanoidAgent
+
 Language::Basic
 
 Language::DATR::DATR2XML
@@ -2775,6 +2895,8 @@ Lingua::JA::Sort::JIS
 
 Lingua::Lexicon::IDP
 
+Lingua::ManagementSpeak
+
 Lingua::PT
 
 Lingua::PT::Conjugate
@@ -2863,6 +2985,8 @@ List::Intersperse
 
 List::Part
 
+List::Rotation::Cycle
+
 List::Util
 
 List::Util::Superpositions
@@ -3013,6 +3137,8 @@ MPEG::MP3Play
 
 MQSeries
 
+MRTG::Parse
+
 MSDOS::Attrib
 
 MSDOS::Descript
@@ -3077,6 +3203,8 @@ Mac::Sound
 
 Mac::Speech
 
+Mac::SysProfile
+
 Mac::Types
 
 Mac::iTunes
@@ -3311,8 +3439,14 @@ Math::RPN
 
 Math::Random
 
+Math::Random::Brownian
+
 Math::Random::MT
 
+Math::Random::MT::Auto
+
+Math::Random::MT::Net
+
 Math::Random::TT800
 
 Math::Round
@@ -3325,6 +3459,8 @@ Math::Spline
 
 Math::Symbolic
 
+Math::Telephony::ErlangB
+
 Math::Trig
 
 Math::VecStat
@@ -3349,6 +3485,8 @@ Metadata::SOIF
 
 Mobile::UserAgent
 
+Mobile::WURFL
+
 Modem::Vgetty
 
 Module::Build
@@ -3371,6 +3509,8 @@ Mon::Client
 
 Mon::SNMP
 
+Mozilla::Backup
+
 Msql
 
 Multimedia::SDP
@@ -3397,6 +3537,8 @@ Net::AOLIM
 
 Net::Address::Ethernet
 
+Net::AudioScrobbler
+
 Net::BEEP::Lite
 
 Net::BGP
@@ -3413,6 +3555,10 @@ Net::CIDR
 
 Net::Chat::Daemon
 
+Net::CyanChat
+
+Net::CyanChat::Server
+
 Net::DHCP
 
 Net::DHCP::Watch
@@ -3423,12 +3569,18 @@ Net::DLookup
 
 Net::DNS
 
+Net::DNS::Check
+
 Net::DNS::DynDNS
 
 Net::DNS::SEC
 
+Net::DNS::TestNS
+
 Net::DNS::Zone::Parser
 
+Net::DRI
+
 Net::Daemon
 
 Net::Daemon::SSL
@@ -3443,6 +3595,10 @@ Net::EPP::Client
 
 Net::FTP
 
+Net::FTP::File
+
+Net::FTP::Versioning
+
 Net::FTPServer
 
 Net::FreeDB
@@ -3519,6 +3675,8 @@ Net::Netrc
 
 Net::OSCAR
 
+Net::OpenSoundControl
+
 Net::P0f
 
 Net::PH
@@ -3559,10 +3717,14 @@ Net::SFTP
 
 Net::SMS
 
+Net::SMS::BulkSMS
+
 Net::SMS::Clickatell
 
 Net::SMS::Genie
 
+Net::SMS::MessageNet
+
 Net::SMS::Web
 
 Net::SMTP
@@ -3589,6 +3751,8 @@ Net::Syslog
 
 Net::TCP
 
+Net::TL1
+
 Net::Telnet
 
 Net::Telnet::Cisco
@@ -3745,6 +3909,8 @@ Number::Format
 
 Number::OutlineNumber
 
+Number::Phone::IE
+
 Number::Phone::PT
 
 Number::Phone::US
@@ -3795,14 +3961,22 @@ Openview::Message
 
 Orac
 
+Oracle::DML
+
 Oracle::Loader
 
 Oracle::OCI
 
 Oracle::SQLLoader
 
+Oracle::Schema
+
+Oracle::Sqlldr
+
 Oracle::Trace
 
+Oracle::Trigger
+
 Oraperl
 
 OurNet
@@ -3811,10 +3985,14 @@ OurNet::BBSApp::Sync
 
 OurNet::FuzzyIndex
 
+OzDB
+
 P4::Client
 
 PAR
 
+PAR::WebStart
+
 PCL::Simple
 
 PDA::Pilot
@@ -3837,6 +4015,8 @@ PDF::PlainLayout
 
 PDF::Report
 
+PDF::ReportWriter
+
 PDF::Reuse
 
 PDF::Reuse::Tutorial
@@ -3885,6 +4065,8 @@ POE::Component::Client::HTTP
 
 POE::Component::Client::Ping
 
+POE::Component::Client::SMTP
+
 POE::Component::Client::TCPMulti
 
 POE::Component::Client::UserAgent
@@ -3929,6 +4111,8 @@ POE::Kernel
 
 POE::Loop::Glib
 
+POE::Loop::Wx
+
 POE::Session
 
 POE::Session::Cascading
@@ -3967,6 +4151,8 @@ Parse::Nessus::ENX
 
 Parse::Nessus::NBE
 
+Parse::Nessus::Plugin
+
 Parse::PlainConfig
 
 Parse::RecDescent
@@ -3997,6 +4183,8 @@ Perl6::Interpolators
 
 Perl6::Parameters
 
+Perl6::Subs
+
 Perl6::Variables
 
 PerlIO
@@ -4067,6 +4255,8 @@ Pod::Parser
 
 Pod::Pdf
 
+Pod::Readme
+
 Pod::Rtf
 
 Pod::Select
@@ -4125,15 +4315,17 @@ PostScript::TextBlock
 
 Postgres
 
+Postgres::Handler
+
 Prima
 
 Proc::Background
 
 Proc::ExitStatus
 
-Proc::Forkfunc
+Proc::Fork
 
-Proc::Forking
+Proc::Forkfunc
 
 Proc::ParallelLoop
 
@@ -4311,6 +4503,8 @@ SGMLS
 
 SICStus
 
+SIL::Shoe
+
 SMIMEUtil
 
 SNMP
@@ -4329,6 +4523,8 @@ SOAP::WSDL
 
 SOOP
 
+SQL::Abstract
+
 SQL::Abstract::Limit
 
 SQL::Builder
@@ -4413,6 +4609,8 @@ Search::FreeText
 
 Search::InvertedIndex
 
+Search::Kinosearch
+
 Search::VectorSpace
 
 Search::Xapian
@@ -4503,8 +4701,12 @@ Solaris::Procfs
 
 Sort::ArbBiLex
 
+Sort::External
+
 Sort::Fields
 
+Sort::Key
+
 Sort::PolySort
 
 Sort::Versions
@@ -4523,8 +4725,14 @@ Splash::DB
 
 Spreadsheet::ParseExcel
 
+Spreadsheet::Read
+
+Spreadsheet::ReadSXC
+
 Spreadsheet::WriteExcel
 
+Spreadsheet::WriteExcel::Worksheet::SheetProtection
+
 Sprite
 
 Stat::lsMode
@@ -4549,6 +4757,8 @@ Statistics::ROC
 
 Statistics::TTest
 
+Stream::Reader
+
 String::Approx
 
 String::BitCount
@@ -4627,6 +4837,8 @@ Syntax::Highlight::Perl
 
 Syntax::Highlight::Shell
 
+Syntax::Highlight::Universal
+
 Sys::AlarmCall
 
 Sys::CPU
@@ -4683,6 +4895,8 @@ TeX::DVI
 
 TeX::Hyphen
 
+Teamspeak
+
 Telephony::CountryDialingCodes
 
 Telephony::Phonedev
@@ -4693,12 +4907,16 @@ Template::Plugin::Config::General
 
 Template::Plugin::Data::HTMLDumper
 
+Template::Plugin::HTML::BBCode
+
 Template::Plugin::SSI
 
 Template::Plugin::StickyQuery
 
 Template::Plugin::Translit::RU
 
+Template::TagParser
+
 Term::ANSIScreen
 
 Term::Activity
@@ -4757,6 +4975,8 @@ Test::File
 
 Test::File::Find::Rule
 
+Test::Fixme
+
 Test::ISBN
 
 Test::LectroTest
@@ -4771,6 +4991,8 @@ Test::MockDBI
 
 Test::MockRandom
 
+Test::MockTime
+
 Test::More
 
 Test::MultiFork
@@ -4831,6 +5053,8 @@ Text::DelimMatch
 
 Text::DoubleMetaphone
 
+Text::Embed
+
 Text::English
 
 Text::EtText
@@ -4839,6 +5063,8 @@ Text::FastTemplate
 
 Text::FillIn
 
+Text::FixEOL
+
 Text::Flowchart::Script
 
 Text::Format
@@ -4849,6 +5075,8 @@ Text::Graphics
 
 Text::Header
 
+Text::Highlight
+
 Text::Iconv
 
 Text::Macros
@@ -4885,8 +5113,12 @@ Text::SimpleTemplate
 
 Text::SpellChecker
 
+Text::Starfish
+
 Text::Stem
 
+Text::StripAccents
+
 Text::Substitute
 
 Text::Table
@@ -4951,6 +5183,8 @@ Tie::Cvs
 
 Tie::Cycle
 
+Tie::Cycle::Sinewave
+
 Tie::DBI
 
 Tie::DB_FileLock
@@ -5083,6 +5317,8 @@ Time::Warp
 
 Time::Zone
 
+Time:Compare
+
 Tk
 
 Tk::ApplicationNest
@@ -5285,6 +5521,8 @@ Tree::Ternary_XS
 
 Tree::Trie
 
+Tuxedo
+
 UDDI
 
 UML::Sequence
@@ -5307,6 +5545,8 @@ URI::Sequin
 
 URI::URL
 
+URI::virtual
+
 UUID
 
 Unicode::EastAsianWidth
@@ -5441,12 +5681,16 @@ WWW::Patent::Page
 
 WWW::Pipeline
 
+WWW::Postini
+
 WWW::Robot
 
 WWW::RobotRules
 
 WWW::Scraper::ISBN
 
+WWW::Scrobbler::Stats
+
 WWW::Search
 
 WWW::Search::AlltheWeb
@@ -5505,12 +5749,18 @@ WebService::GoogleMaps
 
 WebService::Mappoint
 
+WebService::Upcoming
+
+WebSphere::MQTT::Client
+
 WebSphere::Payment
 
 Whitespace
 
 Widget::FixedWidthFont::Input
 
+Wiki::Gateway
+
 Wily
 
 Win32::ADO
@@ -5549,6 +5799,8 @@ Win32::FUtils
 
 Win32::FetchCommand
 
+Win32::File::Summary
+
 Win32::File::VersionInfo
 
 Win32::FileOp
@@ -5583,6 +5835,8 @@ Win32::Message
 
 Win32::Mutex
 
+Win32::Net::Session
+
 Win32::NetAdmin
 
 Win32::NetResource
@@ -5633,6 +5887,8 @@ Win32::UTCFileTime
 
 Win32::WinError
 
+Win32::Word::Writer
+
 Win32API::CommPort
 
 Win32API::File::Time
@@ -5641,10 +5897,14 @@ Win32API::MIDI
 
 Win32API::Registry
 
-WordNet::SenseRelate
+WordNet::SenseRelate::AllWords
+
+WordNet::SenseRelate::TargetWord
 
 WordNet::Similarity
 
+WordNet::Similarity::Visual
+
 Workflow
 
 Wx
@@ -5695,6 +5955,8 @@ XML
 
 XML::ASCX12
 
+XML::ApacheFOP
+
 XML::AutoWriter
 
 XML::CSV
@@ -5755,6 +6017,8 @@ XML::Handler::Trees
 
 XML::LibXML
 
+XML::Merge
+
 XML::Mini
 
 XML::NamespaceSupport
@@ -5767,6 +6031,8 @@ XML::PYX
 
 XML::Parser
 
+XML::Parser::Wrapper
+
 XML::QL
 
 XML::RDB
@@ -5789,6 +6055,8 @@ XML::Simple
 
 XML::Stream
 
+XML::Tidy
+
 XML::TreeBuilder
 
 XML::Twig
@@ -5829,6 +6097,8 @@ YAML
 
 Yahoo::Search
 
+Zeta
+
 dTemplate
 
 define
@@ -5855,6 +6125,8 @@ iCal::Parser::SAX
 
 namespace
 
+xDash
+
 =head1 CHANGES
 
 =over 4
